@@ -16,6 +16,7 @@ package plugin
 
 import (
 	"golang.zabbix.com/sdk/conf"
+	"golang.zabbix.com/sdk/errs"
 	"golang.zabbix.com/sdk/plugin"
 )
 
@@ -51,8 +52,7 @@ type Session struct {
 
 // PluginOptions are options for PostgreSQL connection.
 type PluginOptions struct {
-	plugin.SystemOptions `conf:"optional,name=System"`
-
+	System plugin.SystemOptions `conf:"optional"` //nolint:staticcheck
 	// Timeout is the maximum time in seconds for waiting when a connection has to be established.
 	// Default value equals to the global agent timeout.
 	Timeout int `conf:"optional,range=1:30"`
@@ -77,8 +77,8 @@ type PluginOptions struct {
 // Configure implements the Configurator interface.
 // Initializes configuration structures.
 func (p *Plugin) Configure(global *plugin.GlobalOptions, options interface{}) {
-	if err := conf.Unmarshal(options, &p.options); err != nil {
-		p.Errf("cannot unmarshal configuration options: %s", err)
+	if err := conf.UnmarshalStrict(options, &p.options); err != nil {
+		p.Errf("cannot unmarshal configuration options: %s", err.Error())
 	}
 
 	if p.options.Timeout == 0 {
@@ -95,5 +95,10 @@ func (p *Plugin) Configure(global *plugin.GlobalOptions, options interface{}) {
 func (p *Plugin) Validate(options interface{}) error {
 	var opts PluginOptions
 
-	return conf.Unmarshal(options, &opts)
+	err := conf.UnmarshalStrict(options, &opts)
+	if err != nil {
+		return errs.Wrap(err, "failed to validation options")
+	}
+
+	return nil
 }
